from typing import List, Dict

from peek_core_search._private.PluginNames import searchTuplePrefix
from peek_core_search.tuples.ImportSearchObjectRouteTuple import (
    ImportSearchObjectRouteTuple,
)
from vortex.Tuple import Tuple, addTupleType, TupleField


@addTupleType
class ImportSearchObjectTuple(Tuple):
    """Import Search Object

    This tuple is used by other plugins to load objects into the search index.

    """

    __tupleType__ = searchTuplePrefix + "ImportSearchObjectTuple"

    #:  The unique key for this object
    # This key will be indexed as a full keyword, do not include the key in the keywords
    key: str = TupleField()

    #:  The type of this object
    objectType: str = TupleField()

    #:  Full Keywords
    # The keywords to index that allows the user to search by partial keywords
    # The key of the property will match of create a new "SearchProperty"
    fullKeywords: Dict[str, str] = TupleField({})

    #:  Partial Keywords
    # The keywords to index that allows the user to search by partial keywords
    # The key of the property will match of create a new "SearchProperty"
    partialKeywords: Dict[str, str] = TupleField({})

    #:  The color
    routes: List[ImportSearchObjectRouteTuple] = TupleField([])

    def __repr__(self):
        s = ""
        s += f"key={self.key}\n"
        s += f"objectType={self.objectType}\n"

        for key, value in sorted(self.fullKeywords.items(), key=lambda i: i[0]):
            s += f"fullKw.{key}={value}\n"

        for key, value in sorted(
            self.partialKeywords.items(), key=lambda i: i[0]
        ):
            s += f"partialKw.{key}={value}\n"

        for route in sorted(
            self.routes, key=lambda i: i.routeTitle + i.routePath
        ):
            s += f"route.{route.routeTitle}={route.routePath}\n"

        return s



import logging
from typing import Dict

from peek_abstract_chunked_index.private.server.client_handlers.ACIChunkUpdateHandlerABC import (
    ACIChunkUpdateHandlerABC,
)
from peek_abstract_chunked_index.private.tuples.ACIEncodedChunkTupleABC import (
    ACIEncodedChunkTupleABC,
)
from peek_core_search._private.client.controller.SearchIndexCacheController import (
    clientSearchIndexUpdateFromServerFilt,
)
from peek_core_search._private.storage.EncodedSearchIndexChunk import (
    EncodedSearchIndexChunk,
)

logger = logging.getLogger(__name__)


class ClientSearchIndexChunkUpdateHandler(ACIChunkUpdateHandlerABC):
    _ChunkedTuple: ACIEncodedChunkTupleABC = EncodedSearchIndexChunk
    _updateFromLogicFilt: Dict = clientSearchIndexUpdateFromServerFilt
    _logger: logging.Logger = logger



"""fix exclude comment

Peek Plugin Database Migration Script

Revision ID: 3dba609610b6
Revises: e51cdf9b7d4c
Create Date: 2023-03-01 19:20:30.746630

"""

# revision identifiers, used by Alembic.
revision = '3dba609610b6'
down_revision = 'e51cdf9b7d4c'
branch_labels = None
depends_on = None

import sqlalchemy as sa
from alembic import op


def upgrade():
    op.drop_column("ExcludeSearchString", "comment", schema="core_search")

    op.add_column(
        "ExcludeSearchString",
        sa.Column("comment", sa.String(), nullable=True),
        schema="core_search",
    )


def downgrade():
    op.drop_column("ExcludeSearchString", "comment", schema="core_search")

    op.add_column(
        "ExcludeSearchString",
        sa.Column("comment", sa.Integer(), nullable=True),
        schema="core_search",
    )



"""change chunkKey to str

Peek Plugin Database Migration Script

Revision ID: 62059f03f89f
Revises: 758f26706069
Create Date: 2022-01-19 22:35:35.594735

"""

# revision identifiers, used by Alembic.
revision = "62059f03f89f"
down_revision = "758f26706069"
branch_labels = None
depends_on = None

import sqlalchemy as sa
from alembic import op


def upgrade():
    tables = (
        "EncodedSearchIndexChunk",
        "SearchObjectCompilerQueue",
        "SearchIndex",
        "EncodedSearchObjectChunk",
        "SearchIndexCompilerQueue",
        "SearchObject",
    )

    for table in tables:
        op.alter_column(
            table,
            "chunkKey",
            type_=sa.String(),
            schema="core_search",
        )


def downgrade():
    raise NotImplementedError()
